Learn R Programming

zmisc (version 0.3.0)

.yencode_map: Compile an encoding table for yencode

Description

Compile an encoding table for yencode

Usage

.yencode_map(escape = "%", whitelist = c("._~-", "][!$&'()*+,;=:/?@#"))

Value

A list with the byte lookup table and the multi-byte whitelist entries that need restoring after the byte pass.

Arguments

escape

The escape character to use.

whitelist

Any characters that should not be escaped.