Learn R Programming

zmisc (version 0.3.0)

zmisc-package: zmisc: Vector Look-Ups and Safer Sampling

Description

A collection of utility functions that facilitate looking up vector values from a lookup table, annotate values in a table for clearer viewing, and support a safer approach to vector sampling, sequence generation, and aggregation. Also included is a family of argument checks which return their input so that they compose nicely in a pipe.

Arguments

Author

Maintainer: Magnus Thor Torfason [email protected]

Authors:

Details

For an overview with examples, see the package website at https://torfason.github.io/zmisc/. For the argument checks, see vignette("chk").

See Also