zingle: Return the single (unique) value found in a vector
Description
zingle() returns the only value present in a vector. If the vector contains
more than one distinct value, it throws an error. This is a guard for
aggregations where all values within a group should be identical, but where
you want that assumption checked rather than assumed. Only values are
compared. Names are ignored and the result is unnamed, in line with other
aggregation functions.